@@ -37,8 +37,6 @@
 #include <qtimer.h>
 
 #include "kpLogCategories.h"
-#include <klocale.h>
-
 #include "layers/selections/kpAbstractSelection.h"
 #include "commands/tools/selection/kpAbstractSelectionContentCommand.h"
 #include "commands/kpCommandHistory.h"
@@ -53,6 +51,8 @@
 #include "views/manager/kpViewManager.h"
 #include "imagelib/kpPainter.h"
 
+#include <KLocalizedString>
+
 //---------------------------------------------------------------------
 
 // For either of these timers, they are only active during the "drawing" phase
